import {FadedPreset, ScheduleFaded, SchedulePreset} from "kaneoh-data-types/types/commons/SchedulePreset";
import {TaskConstant} from "../constants/TaskConstant";
import {scheduleStep} from "./scheduleStep";
import * as _ from "underscore";

export function fadedPreset(schedule: SchedulePreset, status: string): FadedPreset {
    const draft: boolean = status === TaskConstant.STATUS.DRAFT;
    const planned: boolean = status === TaskConstant.STATUS.PLANNED;

    const baseline = scheduleStep(schedule, "planned");
    const estimated = scheduleStep(schedule, "projected");
    const actual = scheduleStep(schedule, "actual");

    const isSetEstimated: boolean = _.contains([!!estimated.start, !!estimated.end, !!estimated.duration], true);
    const isSetActual: boolean = _.contains([!!actual.start, !!actual.end, !!actual.duration], true);

    const isOutdatedBaseline: boolean = draft && (isSetEstimated || isSetActual);
    const isOutdatedEstimated: boolean = planned && (isSetActual);

    const startDate: ScheduleFaded = {
        baseline: isOutdatedBaseline && baseline.start,
        estimated: isOutdatedEstimated && estimated.start
    };
    const endDate: ScheduleFaded = {
        baseline: isOutdatedBaseline && baseline.end,
        estimated: isOutdatedEstimated && estimated.end
    };
    const duration: ScheduleFaded = {
        baseline: isOutdatedBaseline && baseline.duration,
        estimated: isOutdatedEstimated && estimated.duration
    };

    return {startDate, endDate, duration} as FadedPreset;
}
